@@ -1,4 +1,5 @@
 # Copyright 2016, Tresys Technology, LLC
+# Copyright 2018, Chris PeBenito <pebenito@ieee.org>
 #
 # This file is part of SETools.
 #
@@ -21,6 +22,8 @@ from collections import namedtuple
 from ..policyrep import ConstraintRuletype
 from .descriptors import DiffResultDescriptor
 from .difference import Difference, SymbolWrapper, Wrapper
+from .objclass import class_wrapper_factory
+from .types import type_wrapper_factory
 
 
 class ConstraintsDifference(Difference):
@@ -191,7 +194,7 @@ class ConstraintWrapper(Wrapper):
     def __init__(self, rule):
         self.origin = rule
         self.ruletype = rule.ruletype
-        self.tclass = SymbolWrapper(rule.tclass)
+        self.tclass = class_wrapper_factory(rule.tclass)
 
         try:
             self.perms = rule.perms
@@ -202,7 +205,7 @@ class ConstraintWrapper(Wrapper):
         self.key = hash(rule)
 
         self.expr = []
-        for op in rule.postfix_expression():
+        for op in rule.expression:
             if isinstance(op, frozenset):
                 # lists of types/users/roles
                 self.expr.append(frozenset(SymbolWrapper(item) for item in op))
@@ -218,6 +221,6 @@ class ConstraintWrapper(Wrapper):
 
     def __eq__(self, other):
         return self.ruletype == other.ruletype and \
-               self.tclass == other.tclass and \
-               self.perms == other.perms and \
-               self.expr == other.expr
+            self.tclass == other.tclass and \
+            self.perms == other.perms and \
+            self.expr == other.expr
