@@ -1,4 +1,5 @@
 # Copyright 2014-2015, Tresys Technology, LLC
+# Copyright 2017, Chris PeBenito <pebenito@ieee.org>
 #
 # This file is part of SETools.
 #
@@ -16,10 +17,7 @@
 # License along with SETools.  If not, see
 # <http://www.gnu.org/licenses/>.
 #
-try:
-    import ipaddress
-except ImportError:  # pragma: no cover
-    pass
+import ipaddress
 
 import logging
 from socket import AF_INET, AF_INET6
@@ -87,10 +85,7 @@ class NodeconQuery(MatchContext, PolicyQuery):
     @network.setter
     def network(self, value):
         if value:
-            try:
-                self._network = ipaddress.ip_network(value)
-            except NameError:  # pragma: no cover
-                raise RuntimeError("Nodecon IP address/network functions require Python 3.3+.")
+            self._network = ipaddress.ip_network(value)
         else:
             self._network = None
 
@@ -108,32 +103,11 @@ class NodeconQuery(MatchContext, PolicyQuery):
         for nodecon in self.policy.nodecons():
 
             if self.network:
-                try:
-                    netmask = ipaddress.ip_address(nodecon.netmask)
-                except NameError:  # pragma: no cover
-                    # Should never actually hit this since the self.network
-                    # setter raises the same exception.
-                    raise RuntimeError("Nodecon IP address/network functions require Python 3.3+.")
-
-                # Python 3.3's IPv6Network constructor does not support
-                # expanded netmasks, only CIDR numbers. Convert netmask
-                # into CIDR.
-                # This is Brian Kernighan's method for counting set bits.
-                # If the netmask happens to be invalid, this will
-                # not detect it.
-                CIDR = 0
-                int_netmask = int(netmask)
-                while int_netmask:
-                    int_netmask &= int_netmask - 1
-                    CIDR += 1
-
-                net = ipaddress.ip_network('{0}/{1}'.format(nodecon.address, CIDR))
-
                 if self.network_overlap:
-                    if not self.network.overlaps(net):
+                    if not self.network.overlaps(nodecon.network):
                         continue
                 else:
-                    if not net == self.network:
+                    if not nodecon.network == self.network:
                         continue
 
             if self.ip_version and self.ip_version != nodecon.ip_version:
